@@ -9,11 +9,11 @@ Module::Format::Module - encapsulates a single Perl module.
 
 =head1 VERSION
 
-Version 0.0.2
+Version 0.0.3
 
 =cut
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 =head1 SYNOPSIS
 
@@ -241,7 +241,7 @@ my @formats_by_priority =
     },
     {
         name => 'unix',
-        regex => qr{\A(?:\w+/)*\.pm\z},
+        regex => qr{\A(?:\w+/)*\w+\.pm\z},
         input => sub {
             my ($class, $value) = @_;
 
